@@ -417,7 +417,7 @@ class MultiRMLPDFWriter(BaseFileWriter):
 
         if self.factory.tempfiles:
             self.factory.reorder_tempfiles([item[2] for item in sorted(self.renderers) if item[2] is not None])
-            self.factory.render_document(self.prepare_filename(self.final_target_filename))
+            self.factory.render_document(self.get_output_filename(self.prepare_filename(self.final_target_filename)))
 
         yield True
 
